#include <gint/display.h>
#include "engine.h"
#include "animation.h"
#include "stalactites.h"
#include "wind.h"

#define ROW(x) x*64

const float GRAVITY = 0.25f;

void engine_tick(struct game *game, int dt)
{
	game->time += dt;

    for (int i=0; i<1; i++){
        struct player *player = game->player;
        player->anim.duration -= dt;
        if(player->anim.duration > 0) continue;

        /* Call the animation function to generate the next frame */
        player->idle = !player->anim.function(&player->anim, 0);
    }

    if(game->stalactites[0].wind || game->stalactites[1].wind){
        for (int i=0; i<1; i++){
            struct wind *wind = game->wind;
            wind->anim.duration -= dt;
            if(wind->anim.duration > 0) continue;

            /* Call the animation function to generate the next frame */
            wind->idle = !wind->anim.function(&wind->anim, 0);
        }
    }

    game->background->x += 1;
    if(game->background->x > 757) game->background-> x = 0;

    stalactites_update(game->stalactites, game);
}

void e_draw_player(struct game const *game)
{     
	dframe(30, game->player->y, game->player->anim.img);
}

void e_update_player(struct game *game)
{
    game->player->yvelocity += GRAVITY;
    game->player->y += game->player->yvelocity;
    dprint_opt(10,10,C_WHITE, C_NONE,DTEXT_LEFT,DTEXT_TOP,"%d", game->score);
    if(wind_touching(game))
        game->player->y += game->player->yvelocity;
}

void e_jump(struct player *player)
{
    player->yvelocity = -3.5; 
    player->idle = !anim_player_jump(&player->anim, 1);
}

void e_draw_background(struct background *background)
{
    extern bopti_image_t img_background;

    dsubimage(0, 0, &img_background, background->x, 0, 396, 224, DIMAGE_NONE);
}

int e_is_dead(struct game const *game)
{
    if(game->player->y > 210) 
        return 1;
    if(stalactites_collide(game))
        return 1;
    return 0;
}
