#include <gint/display.h>
#include <gint/keyboard.h>
#include <gint/timer.h>
#include <gint/clock.h>
#include "engine.h"
#include "stalactites.h"
#include "wind.h"

volatile int timeout = 500;

static int callback_tick(volatile int *tick)
{
    *tick = 1;
    return TIMER_CONTINUE;
}

int main(void)
{
	int FIRSTTIME = 1; 

play:
	static volatile int tick = 1;
	int t = timer_configure(TIMER_ANY, ENGINE_TICK*1000,
		GINT_CALL(callback_tick, &tick));
	if(t < 0) return false;
	timer_start(t);

	struct player player = {
		.y = 108,
		.yvelocity = 0,
		.anim.function = anim_player_idle
	};

	struct wind wind = {
		.anim.function = anim_wind_idle
	};
	
	struct background background = {
		.x = 0
	};

	struct stalactite stalactites[2];

	struct game game = {
		.player = &player,
		.time = 0,
		.background = &background,
		.stalactites = stalactites,
		.wind = &wind,
		.score = 0
	};

	player.idle = !anim_player_idle(&player.anim, 1);
	stalactites_init(stalactites);

	while(FIRSTTIME)
	{ //MENU
		dclear(C_WHITE);
		e_draw_background(&background);
		e_draw_player(&game);
		extern bopti_image_t img_startmenu;
		dimage(0, 0, &img_startmenu);
		dupdate();
		int key = getkey_opt(GETKEY_REP_ALL, &timeout).key;
		if (key == KEY_SHIFT) break;
	}

	FIRSTTIME = 0;

    while(1) //PLAYING
    {
		while(!tick) sleep();
		tick = 0;

        dclear(C_WHITE);
		int key = getkey_opt(GETKEY_REP_ALL, &timeout).key;
		if (key == KEY_UP) e_jump(&player);
		if (key == KEY_MENU) goto stop;
		e_draw_background(&background);
		stalactites_draw(stalactites, &wind);
		e_draw_player(&game);
		e_update_player(&game);
		dupdate();

		if(e_is_dead(&game)) break;

		engine_tick(&game, ENGINE_TICK);
    }	

	while(1)//gameover
	{ 
		dclear(C_WHITE);
		e_draw_background(&background);
		stalactites_draw(stalactites, &wind);
		e_draw_player(&game);
		extern bopti_image_t img_gameover;
		dimage(0, 0, &img_gameover);
		dupdate();
		int key = getkey_opt(GETKEY_REP_ALL, &timeout).key;
		if (key == KEY_SHIFT){
			timer_stop(t);
			goto play;
		};
		if (key == KEY_MENU) break;
	}

stop:
	timer_stop(t);

	return 1;
}

